<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Compressor\Zlib;

// Import framework stuff
use Org\Mxchange\CoreFramework\Compressor\Compressor;
use Org\Mxchange\CoreFramework\Object\BaseFrameworkSystem;

/**
 * ZLIB compression and decompression class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2023 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ZlibCompressor extends BaseFrameworkSystem implements Compressor {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor!
		parent::__construct(__CLASS__);
	}

	/**
	 * Create a new compressor channel based a given compression handler or NULL if the required PHP functions are not found.
	 *
	 * @return	$compressorInstance		An instance of this class or NULL if the required PHP functions are not found.
	 */
	public static final function createZlibCompressor () {
		// Routines not found by default
		$compressorInstance = NULL;

		// Get new instance
		if ((function_exists('gzcompress')) && (function_exists('gzuncompress'))) {
			// Compressor can maybe be used
			$compressorInstance = new ZlibCompressor();
		}

		// Return the compressor instance
		return $compressorInstance;
	}

	/**
	 * ZLIB compression stream
	 *
	 * @param	$streamData		Mixed non-object stream data
	 * @return	$streamData		The compressed stream data
	 */
	public function compressStream (string $streamData) {
		// Compress string
		$streamData = gzcompress($streamData, 1);

		// Return it
		return $streamData;
	}

	/**
	 * ZLIB decompression stream
	 *
	 * @param	$streamData		Mixed non-object stream data
	 * @return	$streamData		The decompressed stream data
	 */
	public function decompressStream (string $streamData) {
		// Return the decompressed stream
		$streamData = gzuncompress($streamData);

		// Return it
		return $streamData;
	}

	/**
	 * Getter for the file extension of this compressor
	 *
	 * @return	$string		Returns always 'z'
	 */
	public final function getCompressorExtension () {
		return 'z';
	}

}
