<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Factory\Registry\Socket;

// Import framework stuff
use Org\Mxchange\CoreFramework\Factory\BaseFactory;
use Org\Mxchange\CoreFramework\Factory\Object\ObjectFactory;
use Org\Mxchange\CoreFramework\Registry\Object\ObjectRegistry;

/**
 * A factory class for socket registries
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2023 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class SocketRegistryFactory extends BaseFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton socket registry instance. If an instance is found in
	 * the registry it will be returned, else a new instance is created and
	 * stored in the same registry entry.
	 *
	 * @return	$registryInstance	A socket registry instance
	 */
	public static final function createSocketRegistryInstance () {
		// Get registry instance
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->traceMessage('SOCKET-REGISTRY-FACTORY: CALLED!');
		$objectRegistryInstance = ObjectRegistry::getRegistry('factory');

		// Do we have an instance in the registry?
		if ($objectRegistryInstance->instanceExists('socket_registry')) {
			// Then use this instance
			/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugMessage('SOCKET-REGISTRY-FACTORY: Getting socket registry instance ...');
			$registryInstance = $objectRegistryInstance->getInstance('socket_registry');
		} else {
			// Get the registry instance
			/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugMessage('SOCKET-REGISTRY-FACTORY: Creating new socket registry instance ...');
			$registryInstance = ObjectFactory::createObjectByConfiguredName('socket_registry_class');

			// Set the instance in registry for further use
			/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugMessage('SOCKET-REGISTRY-FACTORY: Adding socket registry instance ...');
			$objectRegistryInstance->addInstance('socket_registry', $registryInstance);
		}

		// Return the instance
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->traceMessage(sprintf('SOCKET-REGISTRY-FACTORY: registryInstance=%s - EXIT!', $registryInstance->__toString()));
		return $registryInstance;
	}

}
