<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Filesystem\File;

// Import framework stuff
use Org\Mxchange\CoreFramework\Filesystem\File\BaseAbstractFile;
use Org\Mxchange\CoreFramework\Generic\FrameworkInterface;
use Org\Mxchange\CoreFramework\Generic\UnsupportedOperationException;

// Import SPL stuff
use \SplFileInfo;

/**
 * A general text file class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2023 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
abstract class BaseTextFile extends BaseAbstractFile {
	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct (string $className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Determines seek position
	 *
	 * @return	$seekPosition	Current seek position
	 */
	public function determineSeekPosition () {
		// Not possible in text files
		throw new UnsupportedOperationException([$this, __FUNCTION__], FrameworkInterface::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Seek to given offset (default) or other possibilities as fseek() gives.
	 *
	 * @param	$offset		Offset to seek to (or used as "base" for other seeks)
	 * @param	$whence		Added to offset (default: only use offset to seek to)
	 * @return	$status		Status of file seek: 0 = success, -1 = failed
	 */
	public function seek (int $offset, int $whence = SEEK_SET) {
		// Not possible in text files
		self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('BASE-TEXT-FILE: offset=' . $offset . ',whence=' . $whence);
		throw new UnsupportedOperationException([$this, __FUNCTION__], FrameworkInterface::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Reads from a local or remote file
	 *
	 * @param	$infoInstance	An instance of a SplFileInfo class
	 * @return	$array	An array containing all read lines
	 * @throws	InvalidArrayCountException	If an array has not the expected size
	 * @throws	InvalidMD5ChecksumException	If two MD5 hashes did not match
	 */
	public function loadFileContents (SplFileInfo $infoInstance) {
		/*
		 * This class (or its implementations) are special file readers/writers.
		 * There is no need to read/write the whole file.
		 */
		self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('BASE-TEXT-FILE: infoInstance=' . $infoInstance);
		throw new UnsupportedOperationException([$this, __FUNCTION__], FrameworkInterface::EXCEPTION_UNSPPORTED_OPERATION);
	}

}
