<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Registry;

/**
 * A registry for several data types and objects. Objects should be added by
 * addInstance() and therefore must implement the interface Registerable.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2023 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class GenericRegistry extends BaseRegistry implements Register {
	/**
	 * Instance of this class
	 */
	private static $registryInstance = NULL;

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Singleton getter for self instance. This class has no factory pattern
	 * because here is no need for special parameters.
	 *
	 * @param	$key	Key for for this instance
	 * @return	$registryInstance	Instance of this class
	 * @throws	InvalidArgumentException	If a parameter has an invalid value
	 */
	public static final function getRegistry (string $key) {
		// Check parameter
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->traceMessage(sprintf('OBJECT-REGISTRY: key=%s - CALLED!', $key));
		if (empty($key)) {
			// Throw IAE
			throw new InvalidArgumentException('Parameter "key" is empty');
		}

		// Is an instance there?
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugMessage(sprintf('OBJECT-REGISTRY: self::registryInstance[%s]?=%d', $key, intval(isset((self::$registryInstances[$key])))));
		if (!isset(self::$registryInstances[$key])) {
			// Not yet, so create one
			self::$registryInstances[$key] = new ObjectRegistry();
		}

		// Return the instance
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->traceMessage(sprintf('OBJECT-REGISTRY: self::registryInstance[%s]=%s - EXIT!', $key, self::$registryInstances[$key]->__toString()));
		return self::$registryInstances[$key];
	}

}
