<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Generic;

/**
 * This is the top-level interface for all other interfaces and should contain
 * method stubs which is being used in every class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2023 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @todo		Find a better name for this interface
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface FrameworkInterface {
	// Exception constants
	const EXCEPTION_INVALID_ARGUMENT     = 0x200;
	const EXCEPTION_LOGIC_EXCEPTION      = 0x201;
	const EXCEPTION_UNSPPORTED_OPERATION = 0x202;
	const EXCEPTION_UNEXPECTED_VALUE     = 0x203;
	const EXCEPTION_CLASS_NOT_FOUND      = 0x204;
	const EXCEPTION_BAD_METHOD_CALL      = 0x205;
	const EXCEPTION_OUT_OF_BOUNDS        = 0x206;

	/**
	 * Getter for field name
	 *
	 * @param	$fieldName		Field name which we shall get
	 * @return	$fieldValue		Field value from the user
	 * @throws	NullPointerException	If the result instance is null
	 */
	function getField (string $fieldName);

	/**
	 * Checks if given field is set
	 *
	 * @param	$fieldName	Field name to check
	 * @return	$isSet		Whether the given field name is set
	 * @throws	NullPointerException	If the result instance is null
	 */
	function isFieldSet (string $fieldName);

	/**
	 * Setter for call-back instance
	 *
	 * @param	$callbackInstance	An instance of a FrameworkInterface class
	 * @return	void
	 */
	function setCallbackInstance (FrameworkInterface $callbackInstance);

	/**
	 * Checks whether an object equals this object. You should overwrite this
	 * method to implement own equality checks
	 *
	 * @param	$objectInstance		An instance of a FrameworkInterface object
	 * @return	$equals				Whether both objects equals
	 */
	function equals (FrameworkInterface $objectInstance);

	/**
	 * Generates a code for hashes from this class
	 *
	 * @return	$hashCode	The hash code respresenting this class
	 */
	function hashCode ();

}
